==> v0.5.0.zip: epervier-old/examples/gameplay/plateform/init.lua <==
-- example/plateform :: a dead simple plateformer example

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene = require "gamecore.modules.scenes"
local Plateformer = Scene:extend()

local World = require "gamecore.modules.world.world2D"
local Pause = require "examples.gameplay.plateform.pause"

function Plateformer:new()
  Plateformer.super.new(self)

  local folder = "examples.gameplay.plateform"

  self.assets:batchImport("examples.gameplay.plateform.assets")

  World(self, folder .. ".actors", "examples/gameplay/plateform/assets/platformer.lua")

  Pause(self)
  self.menusystem:deactivate()
  self.menusystem:lockWorldWhenActive(true)
  self.menusystem:lockAssetsWhenActive(true)

  self.world:loadMap()
end

function Plateformer:restart()
  self.menusystem:deactivate()
  collectgarbage()
  self.world:reset()
end

function Plateformer:update(dt)
  if (self.menusystem.isActive == true) and self.sources[1].keys["start"].isPressed then
    self.menusystem:deactivate()
  end
end

function Plateformer:draw()
  if (self.world.isActive == false) then
    local w, h = core.screen:getDimensions()
    love.graphics.setColor(1, 1, 0, 1)
    love.graphics.printf("PAUSE", 0,  24*3, w, "center")
    utils.graphics.resetColor()
  end
end

return Plateformer

==> v0.6.0rc1.zip: epervier-old/examples/gameplay/plateform/init.lua <==
-- example/plateform :: a dead simple plateformer example

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene = require "gamecore.modules.scenes"
local Plateformer = Scene:extend()

local World = require "gamecore.modules.world.world2D"
local Pause = require "examples.gameplay.plateform.pause"

function Plateformer:new()
  Plateformer.super.new(self)

  local folder = "examples.gameplay.plateform"

  self.assets:batchImport("examples.gameplay.plateform.assets")

  World(self, folder .. ".actors", "datas/maps/plateformer/platformer.lua")

  Pause(self)
  self.menusystem:deactivate()
  self.menusystem:lockWorldWhenActive(true)
  self.menusystem:lockAssetsWhenActive(true)

  self.world:loadMap()
end

function Plateformer:restart()
  self.menusystem:deactivate()
  collectgarbage()
  self.world:reset()
end

function Plateformer:update(dt)
  if (self.menusystem.isActive == true) and self.sources[1].keys["start"].isPressed then
    self.menusystem:deactivate()
  end
end

function Plateformer:draw()
  if (self.world.isActive == false) then
    local w, h = core.screen:getDimensions()
    love.graphics.setColor(1, 1, 0, 1)
    love.graphics.printf("PAUSE", 0,  24*3, w, "center")
    utils.graphics.resetColor()
  end
end

return Plateformer
